@@ -7,7 +7,7 @@ use threads;
 use threads::shared;
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 my $self;
 
@@ -16,12 +16,13 @@ $| = 1;
 $SIG{'INT'} = \&stop;
 
 my $spin : shared = 1;
+my $showSpin : shared = 0;
 
 async{
 	while($spin){
 		do{
 			select undef, undef, undef, 0.1;
-			printf "$_\b";
+			printf "$_\b" if $showSpin;
 		}
 		for qw(/ - \ |);
 	}
@@ -36,7 +37,7 @@ sub new{
 		minSupport => undef,
 		minConfidence => undef,
 		output => undef,
-		messages => shift,
+		messages => undef,
 		itemsKeyDescription => undef,
 		itemsKeyTransactions => undef,
 		quantityPossibleRules => undef,
@@ -47,7 +48,6 @@ sub new{
 		rule => 0
 	};
 	@{$self->{frequentItemset}}=();
-	$spin=$self->{messages};
 	bless($self,$class);
 	return $self;
 }
@@ -99,9 +99,13 @@ sub association_rules_itemset_size{
 	}
 	my @newItemsetCandidateSizeOne = ();
 	if($self->{messages}){
+		$showSpin=1;
 		print "\n\nItemset size ", $self->{itemsetSize}, ", ", scalar(@itemsetCandidateSizeOne), " items ";
 		print "\nProcessing... ";
 	}
+	else{
+		$spin=0;
+	}
 	for(my$itemsetSize=2;$itemsetSize<=$itemsetSizeLimit;$itemsetSize++){
 		my $code=<<'CODE';
 my @itemsetCandidate=();
@@ -203,6 +207,7 @@ sub stop{
 	if($self->{messages}){
 		print "\nStopping... ";
 		$self->output if $self->{associationRules};
+		$showSpin=0;		
 		print "\nExit? (Y/N): ";
 		my $exit = <STDIN>;
 		chomp($exit);
@@ -210,6 +215,7 @@ sub stop{
 			exit;
 		}
 		else{
+			$showSpin=1;
 			print "\nProcessing... ";
 		}
 	}
@@ -275,23 +281,23 @@ sub excel{
 		push @support,${$self->{associationRules}{$rule}{"R$rule"}{rule}}[1];
 		push @confidence,${$self->{associationRules}{$rule}{"R$rule"}{rule}}[2];
 	}
-	my$end=(scalar(@rules)+1);
+	my$line=(scalar(@rules)+1);
 	my@data=(\@rules,\@support,\@confidence);
 	$worksheet->write('A1', $headings, $bold);
 	$worksheet->write('A2', \@data);
 	my$chart=$workbook->add_chart(type => 'column', embedded => 1);
 	$chart->add_series(
 		name       => 'Support %',
-		categories => '=Sheet1!$A$2:$A$'.$end,
-		values     => '=Sheet1!$B$2:$B$'.$end,
+		categories => '=Sheet1!$A$2:$A$'.$line,
+		values     => '=Sheet1!$B$2:$B$'.$line,
 	);
 	$chart->add_series(
 		name       => 'Confidence %',
-		categories => '=Sheet1!$A$2:$A$'.$end,
-		values     => '=Sheet1!$C$2:$C$'.$end,
+		categories => '=Sheet1!$A$2:$A$'.$line,
+		values     => '=Sheet1!$C$2:$C$'.$line,
 	);
 	$worksheet->insert_chart('H2', $chart);
-	my$line=($end+2);
+	$line+=2;
 	foreach my$rule(sort{$a<=>$b}keys(%{$self->{associationRules}})){
 		$worksheet->write("A$line","Rule R$rule: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[0]");
 		$line++;
@@ -342,15 +348,17 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 	#        1109          1        1         1
 	#        1110          1        1         1
 
-	my $apriori = Data::Mining::Apriori->new(1); # A value boolean to display the messages(optional)
-	 
+	my $apriori = new Data::Mining::Apriori;
+
 	$apriori->{totalTransactions}=10; # The total number of transactions
 
 	$apriori->{minSupport}=1.55; # The minimum support
 
 	$apriori->{minConfidence}=1.55; # The minimum confidence
 
-	$apriori->{output}=1; # The output type (1 - Export to file; 2 - Export to excel)(optional)
+	$apriori->{output}=1; # The output type (1 - Export to file; 2 - Export to excel.)(optional)
+
+	$apriori->{messages}=1; # A value boolean to display the messages(optional)
 
 	$apriori->{itemsKeyDescription}{'101'}='MILK'; # Hash table to add items by key and description
 	$apriori->{itemsKeyDescription}{102}='BREAD';
@@ -434,7 +442,7 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 	$query->execute;
 	my $totalTransactions = $query->fetchrow;
 
-	$apriori = Data::Mining::Apriori->new(1);
+	$apriori = new Data::Mining::Apriori;
 
 	$apriori->{totalTransactions}=$totalTransactions;
 
@@ -444,6 +452,8 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 
 	$apriori->{output}=1;
 
+	$apriori->{messages}=1;
+
 	my $support = int((($apriori->{totalTransactions}/100)*$apriori->{minSupport}));
 
 	$sql = qq~
@@ -508,15 +518,15 @@ The output type (optional):
 
 =over 4
 
-=item *
+=item 1 - Export to file;
 
-1 - Export to file;
+=item 2 - Export to excel.
 
-=over 4
+=back
 
-=item *
+=head2 messages
 
-2 - Export to excel.
+A value boolean to display the messages(optional).
 
 =head2 itemsKeyDescription
 
@@ -544,12 +554,6 @@ A value boolean to generate association rules until no set of items meets the mi
 
 Creates a new instance of Data::Mining::Apriori.
 
-=over 4
-
-=item *
-
-Expected a value boolean to display the messages(optional).
-
 =head2 generate_rules
 
 Generate association rules until no set of items meets the minimum support or minimum confidence.
@@ -560,7 +564,9 @@ Generates association rules by size set of items. Accepts the following argument
 
 =over 4
 
-=item * An integer
+=item *
+
+An integer.
 
 Representing the size of the set of items.
 
@@ -572,11 +578,10 @@ Alex Graciano, E<lt>agraciano@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 by Alex Graciano
+Copyright (C) 2015-2016 by Alex Graciano
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.12.4 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
